==> docfbe_2_3_46_82.zip: docfbe_2_3_46_82/source/TCFbETypes.h <==
#ifndef TCFbETypesH
#define TCFbETypesH
//---------------------------------------------------------------------------
// CFbE ŋʂĎgp^錾wb_
//---------------------------------------------------------------------------
// }[W@w肷񋓌^
enum TMergeBase { tmbNone, tmbBoth, tmbLearningData, tmbEstimatingData };
// tmbNone:                }[WȂ
// tmbBoth:                LearningData, EstimatingData ̗c
// tmbLearningData:     LearningData ̗񂾂c
// tmbEstimatingData:    EstimatingData ̗񂾂c

// g[jOf[^̐\񋓌^
enum TTargetColumnType { tmtTooSparsity=-1, tmtEmpty=0, tmtPredictable=1 };
// tmtEmpty:        f[^݂Ȃ
// tmtPredictable:    \\ȃgNX
// tmtTooSparsity:    \s\ȃgNXiNeighborsSize g[jOf[^Ȃ

// m[}CY@
enum TCFbEValueBase { vbUnknown, vbValue, vbStandardizedValue, vbNormalizedValue, vbOrder };

// x[X̃ASYiabUnknown Ȃ abRow ƓlƂ݂Ȃ
enum TCFbEAlgorithmBase { abUnknown, abRow, abColumn };

// G[R[h
enum TCFbEErrorCode {
    ecNone = 0,

    ecNoLearningDataFileName        = 1,
    ecLearningDataNotFound          = 2,
    ecNoEstimatingDataFileName      = 3,
    ecNoSimilarityComputationAlgorithm      = 4,
    ecNoPredictionAlgorithm         = 5,
    ecTooLongCommandLineArguments   = 6,
    ecIllegalOption                 = 7,

    ecEstimatingDataNotFound        = -1,
    ecIllegalSimilarityComputationAlgorithm = -2,
    ecIllegalPredictionAlgorithm    = -3,
    ecIllegalNormalizationMethod    = -4,
    ecIllegalNeighborsSize          = -5,
    ecOutputDirectoryCantBeMade     = -6,
    ecLearningDataCantBeOpened      = -7,
    ecEstimatingDataCantBeOpened    = -8,
    ecDatasetsAreInconsistency      = -9,
    ecLearningDataHasNoTargetedColumn   = -10,
    ecLearningDataHasLessTargetdData    = -11,
    ecOutputFileCantBeWritten       = -12,
    ecUnknown                       = -13,
    ecIllegalDefaultValue           = -14,
    ecIllegalMergeBase              = -15,
    ecIllegalCaseAmplifier          = -16,
    ecIllegalVWSimilarityAlgorithm  = -17,
    ecIllegalVWPredictionAlgorithm  = -18,
    ecVWPredictionAlgorithmIllegallySpecified   = -19,
    ecNoTargetColumn                = -20,
    ecNoVWPredictionAlgorithm       = -21,
    ecIllegalCombinedRatio          = -22,
    ecDuplicatedRow                 = -23,
    ecDuplicatedColumn              = -24,
    ecRowIsContainedBothFile        = -25
};
//---------------------------------------------------------------------------
#endif

==> docfbe_2_4_47_83.zip: docfbe_2_4_47_83/source/TCFbETypes.h <==
#ifndef TCFbETypesH
#define TCFbETypesH
//---------------------------------------------------------------------------
// CFbE ŋʂĎgp^錾wb_
//---------------------------------------------------------------------------
// XyV[hŃRpC
// #define SPECIAL_MODE

// }[W@w肷񋓌^
enum TMergeBase { tmbNone, tmbBoth, tmbLearningData, tmbEstimatingData };
// tmbNone:                }[WȂ
// tmbBoth:                LearningData, EstimatingData ̗c
// tmbLearningData:     LearningData ̗񂾂c
// tmbEstimatingData:    EstimatingData ̗񂾂c

// g[jOf[^̐\񋓌^
enum TTargetColumnType { tmtTooSparsity=-1, tmtEmpty=0, tmtPredictable=1 };
// tmtEmpty:        f[^݂Ȃ
// tmtPredictable:    \\ȃgNX
// tmtTooSparsity:    \s\ȃgNXiNeighborsSize g[jOf[^Ȃ

// m[}CY@
enum TCFbEValueBase { vbUnknown, vbValue, vbStandardizedValue, vbNormalizedValue, vbOrder };

// x[X̃ASYiabUnknown Ȃ abRow ƓlƂ݂Ȃ
enum TCFbEAlgorithmBase { abUnknown, abRow, abColumn };

// G[R[h
enum TCFbEErrorCode {
    ecNone = 0,

    ecNoLearningDataFileName        = 1,
    ecLearningDataNotFound          = 2,
    ecNoEstimatingDataFileName      = 3,
    ecNoSimilarityComputationAlgorithm      = 4,
    ecNoPredictionAlgorithm         = 5,
    ecTooLongCommandLineArguments   = 6,
    ecIllegalOption                 = 7,
    ecNoQualitativeIndicator        = 8,

    ecEstimatingDataNotFound        = -1,
    ecIllegalSimilarityComputationAlgorithm = -2,
    ecIllegalPredictionAlgorithm    = -3,
    ecIllegalNormalizationMethod    = -4,
    ecIllegalNeighborsSize          = -5,
    ecOutputDirectoryCantBeMade     = -6,
    ecLearningDataCantBeOpened      = -7,
    ecEstimatingDataCantBeOpened    = -8,
    ecDatasetsAreInconsistency      = -9,
    ecLearningDataHasNoTargetedColumn   = -10,
    ecLearningDataHasLessTargetdData    = -11,
    ecOutputFileCantBeWritten       = -12,
    ecUnknown                       = -13,
    ecIllegalDefaultValue           = -14,
    ecIllegalMergeBase              = -15,
    ecIllegalCaseAmplifier          = -16,
    ecIllegalVWSimilarityAlgorithm  = -17,
    ecIllegalVWPredictionAlgorithm  = -18,
    ecVWPredictionAlgorithmIllegallySpecified   = -19,
    ecNoTargetColumn                = -20,
    ecNoVWPredictionAlgorithm       = -21,
    ecIllegalCombinedRatio          = -22,
    ecDuplicatedRow                 = -23,
    ecDuplicatedColumn              = -24,
    ecRowIsContainedBothFile        = -25,
    ecIllegalLogBase                = -26,
    ecIllegalCombinedSimilarityAlgorithm    = -27
};
//---------------------------------------------------------------------------
#endif
